@@ -1,5 +1,7 @@
 """
-Main interface for comprehend service literal definitions.
+Type annotations for comprehend service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/literals.html)
 
 Usage::
 
